#![allow(dead_code)]

pub const U16_TAB: u16 = 9;
pub const U16_NEWLINE: u16 = 10;
pub const U16_SPACE: u16 = 32;
pub const U16_FACTORIAL: u16 = 33;
pub const U16_DOUBLE_QUOTE: u16 = 34;
pub const U16_SHARP: u16 = 35;
pub const U16_AMPERSAND: u16 = 38;
pub const U16_SINGLE_QUOTE: u16 = 39;
pub const U16_LEFT_PARENTHESIS: u16 = 40;
pub const U16_RIGHT_PARENTHESIS: u16 = 41;
pub const U16_ASTERISK: u16 = 42;
pub const U16_COMMA: u16 = 44;
pub const U16_MINUS: u16 = 45;
pub const U16_DOT: u16 = 46;
pub const U16_SLASH: u16 = 47;
pub const U16_1: u16 = 49;
pub const U16_COLON: u16 = 58;
pub const U16_SEMI_COLON: u16 = 59;
pub const U16_LESS_THAN: u16 = 60;
pub const U16_EQUAL: u16 = 61;
pub const U16_GREATER_THAN: u16 = 62;
pub const U16_BIG_A: u16 = 65;
pub const U16_BIG_I: u16 = 73;
pub const U16_BIG_X: u16 = 88;
pub const U16_BIG_Z: u16 = 90;
pub const U16_LEFT_SQUARE_BRACKET: u16 = 91;
pub const U16_BACKSLASH: u16 = 92;
pub const U16_RIGHT_SQUARE_BRACKET: u16 = 93;
pub const U16_CARET: u16 = 94;
pub const U16_UNDERBAR: u16 = 95;
pub const U16_BACKTICK: u16 = 96;
pub const U16_SMALL_A: u16 = 97;
pub const U16_SMALL_B: u16 = 98;
pub const U16_SMALL_C: u16 = 99;
pub const U16_SMALL_D: u16 = 100;
pub const U16_SMALL_E: u16 = 101;
pub const U16_SMALL_F: u16 = 102;
pub const U16_SMALL_G: u16 = 103;
pub const U16_SMALL_H: u16 = 104;
pub const U16_SMALL_I: u16 = 105;
pub const U16_SMALL_K: u16 = 107;
pub const U16_SMALL_L: u16 = 108;
pub const U16_SMALL_M: u16 = 109;
pub const U16_SMALL_N: u16 = 110;
pub const U16_SMALL_O: u16 = 111;
pub const U16_SMALL_P: u16 = 112;
pub const U16_SMALL_Q: u16 = 113;
pub const U16_SMALL_R: u16 = 114;
pub const U16_SMALL_S: u16 = 115;
pub const U16_SMALL_T: u16 = 116;
pub const U16_SMALL_U: u16 = 117;
pub const U16_SMALL_V: u16 = 118;
pub const U16_SMALL_W: u16 = 119;
pub const U16_SMALL_X: u16 = 120;
pub const U16_SMALL_Y: u16 = 121;
pub const U16_SMALL_Z: u16 = 122;
pub const U16_LEFT_CURLY_BRACE: u16 = 123;
pub const U16_VERTICAL_BAR: u16 = 124;
pub const U16_RIGHT_CURLY_BRACE: u16 = 125;
pub const U16_TILDE: u16 = 126;


pub const BACKSLASH_ESCAPE_MARKER: u16 = 0xf000;